@@ -11,9 +11,3 @@ class RequestError(SimplipyError):
     """Define an error related to invalid requests."""
 
     pass
-
-
-class TokenExpiredError(SimplipyError):
-    """Define an error for expired access tokens."""
-
-    pass
