@@ -3,6 +3,8 @@ import logging
 from enum import Enum
 from typing import Union
 
+from .errors import SimplipyError
+
 _LOGGER = logging.getLogger(__name__)
 
 
@@ -75,10 +77,20 @@ class SensorV2(Sensor):
         """Return the sensor's settings."""
         return self.sensor_data['setting']
 
+    @property
+    def trigger_instantly(self) -> bool:
+        """Return whether the sensor will trigger instantly."""
+        return self.sensor_data['instant']
+
     @property
     def triggered(self) -> bool:
         """Return the current sensor state."""
-        return self.sensor_data.get('sensorStatus', 0) != 0
+        if self.type == SensorTypes.entry:
+            return self.sensor_data.get('entryStatus', 'closed') == 'open'
+
+        raise SimplipyError(
+            'Cannot determine triggered state for sensor: {0}'.format(
+                self.name))
 
 
 class SensorV3(Sensor):
@@ -104,6 +116,11 @@ class SensorV3(Sensor):
         """Return the sensor's settings."""
         return self.sensor_data['setting']
 
+    @property
+    def trigger_instantly(self) -> bool:
+        """Return whether the sensor will trigger instantly."""
+        return self.sensor_data['setting']['instantTrigger']
+
     @property
     def triggered(self) -> bool:
         """Return the sensor's status info."""
